"""drop build_context columns

Revision ID: ce57a9d1f1a9
Revises: 3e70da4a33c9
Create Date: 2026-06-13 18:34:25.196976

"""

from collections.abc import Sequence

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "ce57a9d1f1a9"
down_revision: str | Sequence[str] | None = "3e70da4a33c9"
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("jobs", "build_context")
    op.drop_column("registered_jobs", "build_context")
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("registered_jobs", sa.Column("build_context", sa.VARCHAR(), autoincrement=False, nullable=True))
    op.add_column("jobs", sa.Column("build_context", sa.VARCHAR(), autoincrement=False, nullable=True))
    # ### end Alembic commands ###
